==> qmmp-1.6.8.tar.bz2: qmmp-1.6.8/src/plugins/General/copypaste/translations/copypaste_plugin_sv.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sv">
<context>
    <name>CopyPaste</name>
    <message>
        <location filename="../copypaste.cpp" line="41"/>
        <source>Cu&amp;t</source>
        <translation>Kl&amp;ipp ut</translation>
    </message>
    <message>
        <location filename="../copypaste.cpp" line="42"/>
        <source>Ctrl+X</source>
        <translation>Ctrl+X</translation>
    </message>
    <message>
        <location filename="../copypaste.cpp" line="43"/>
        <source>&amp;Copy</source>
        <translation>&amp;Kopiera</translation>
    </message>
    <message>
        <location filename="../copypaste.cpp" line="44"/>
        <source>Ctrl+C</source>
        <translation>Ctrl+C</translation>
    </message>
    <message>
        <location filename="../copypaste.cpp" line="45"/>
        <source>&amp;Paste</source>
        <translation>&amp;Klistra in</translation>
    </message>
    <message>
        <location filename="../copypaste.cpp" line="46"/>
        <source>Ctrl+V</source>
        <translation>Ctrl+V</translation>
    </message>
</context>
<context>
    <name>CopyPasteFactory</name>
    <message>
        <location filename="../copypastefactory.cpp" line="29"/>
        <source>Copy/Paste Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../copypastefactory.cpp" line="49"/>
        <source>About Copy/Paste Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../copypastefactory.cpp" line="50"/>
        <source>Qmmp Copy/Paste Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../copypastefactory.cpp" line="51"/>
        <source>This plugin allows one to copy selected tracks from one playlist to another</source>
        <translation>Detta plugin låter en kopiera valda spår från en spellista till en annan</translation>
    </message>
    <message>
        <location filename="../copypastefactory.cpp" line="52"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Skriven av: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
</TS>

==> qmmp_2.3.0.orig.tar.bz2: qmmp-2.3.0/src/plugins/General/copypaste/translations/copypaste_plugin_sv.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sv_SE">
<context>
    <name>CopyPaste</name>
    <message>
        <location filename="../copypaste.cpp" line="41"/>
        <source>Cu&amp;t</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../copypaste.cpp" line="42"/>
        <source>Ctrl+X</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../copypaste.cpp" line="43"/>
        <source>&amp;Copy</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../copypaste.cpp" line="44"/>
        <source>Ctrl+C</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../copypaste.cpp" line="45"/>
        <source>&amp;Paste</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../copypaste.cpp" line="46"/>
        <source>Ctrl+V</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CopyPasteFactory</name>
    <message>
        <location filename="../copypastefactory.cpp" line="28"/>
        <source>Copy/Paste Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../copypastefactory.cpp" line="48"/>
        <source>About Copy/Paste Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../copypastefactory.cpp" line="49"/>
        <source>Qmmp Copy/Paste Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../copypastefactory.cpp" line="50"/>
        <source>This plugin allows one to copy selected tracks from one playlist to another</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../copypastefactory.cpp" line="51"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
